@@ -3,7 +3,7 @@
 use Shell::Cmd;
 $obj = new Shell::Cmd;
 $obj->options("echo" => "echo");
-$obj->options("run"  => "dry-run");
+$obj->options("mode" => "dry-run");
 $obj->cmd(q(echo "Dollar \$ Backtick \` Backslash \\\\ Quote \\""));
 $obj->cmd("ls /tmp");
 ($script) = $obj->run();
